# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: oracle/v1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from oracle.v1 import oracle_pb2 as oracle_dot_v1_dot_oracle__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='oracle/v1/tx.proto',
  package='oracle.v1',
  syntax='proto3',
  serialized_options=b'Z,github.com/bandprotocol/chain/x/oracle/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x12oracle/v1/tx.proto\x12\toracle.v1\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\x1a\x16oracle/v1/oracle.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\xc9\x02\n\x0eMsgRequestData\x12>\n\x10oracle_script_id\x18\x01 \x01(\x03\x42$\xe2\xde\x1f\x0eOracleScriptID\xfa\xde\x1f\x0eOracleScriptID\x12\x10\n\x08\x63\x61lldata\x18\x02 \x01(\x0c\x12\x11\n\task_count\x18\x03 \x01(\x04\x12\x11\n\tmin_count\x18\x04 \x01(\x04\x12\x1f\n\tclient_id\x18\x05 \x01(\tB\x0c\xe2\xde\x1f\x08\x43lientID\x12^\n\tfee_limit\x18\x06 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12\x13\n\x0bprepare_gas\x18\x07 \x01(\x04\x12\x13\n\x0b\x65xecute_gas\x18\x08 \x01(\x04\x12\x0e\n\x06sender\x18\t \x01(\t:\x04\xe8\xa0\x1f\x01\"\x18\n\x16MsgRequestDataResponse\"\x9b\x01\n\rMsgReportData\x12.\n\nrequest_id\x18\x01 \x01(\x03\x42\x1a\xe2\xde\x1f\tRequestID\xfa\xde\x1f\tRequestID\x12/\n\x0braw_reports\x18\x02 \x03(\x0b\x32\x14.oracle.v1.RawReportB\x04\xc8\xde\x1f\x00\x12\x11\n\tvalidator\x18\x03 \x01(\t\x12\x10\n\x08reporter\x18\x04 \x01(\t:\x04\xe8\xa0\x1f\x01\"\x17\n\x15MsgReportDataResponse\"\xdd\x01\n\x13MsgCreateDataSource\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x12\n\nexecutable\x18\x03 \x01(\x0c\x12X\n\x03\x66\x65\x65\x18\x04 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12\x10\n\x08treasury\x18\x05 \x01(\t\x12\r\n\x05owner\x18\x06 \x01(\t\x12\x0e\n\x06sender\x18\x07 \x01(\t:\x04\xe8\xa0\x1f\x01\"\x1d\n\x1bMsgCreateDataSourceResponse\"\x95\x02\n\x11MsgEditDataSource\x12\x38\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\x03\x42 \xe2\xde\x1f\x0c\x44\x61taSourceID\xfa\xde\x1f\x0c\x44\x61taSourceID\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x12\n\nexecutable\x18\x04 \x01(\x0c\x12X\n\x03\x66\x65\x65\x18\x05 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12\x10\n\x08treasury\x18\x06 \x01(\t\x12\r\n\x05owner\x18\x07 \x01(\t\x12\x0e\n\x06sender\x18\x08 \x01(\t:\x04\xe8\xa0\x1f\x01\"\x1b\n\x19MsgEditDataSourceResponse\"\xa9\x01\n\x15MsgCreateOracleScript\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06schema\x18\x03 \x01(\t\x12*\n\x0fsource_code_url\x18\x04 \x01(\tB\x11\xe2\xde\x1f\rSourceCodeURL\x12\x0c\n\x04\x63ode\x18\x05 \x01(\x0c\x12\r\n\x05owner\x18\x06 \x01(\t\x12\x0e\n\x06sender\x18\x07 \x01(\t:\x04\xe8\xa0\x1f\x01\"\x1f\n\x1dMsgCreateOracleScriptResponse\"\xe7\x01\n\x13MsgEditOracleScript\x12>\n\x10oracle_script_id\x18\x01 \x01(\x03\x42$\xe2\xde\x1f\x0eOracleScriptID\xfa\xde\x1f\x0eOracleScriptID\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0e\n\x06schema\x18\x04 \x01(\t\x12*\n\x0fsource_code_url\x18\x05 \x01(\tB\x11\xe2\xde\x1f\rSourceCodeURL\x12\x0c\n\x04\x63ode\x18\x06 \x01(\x0c\x12\r\n\x05owner\x18\x07 \x01(\t\x12\x0e\n\x06sender\x18\x08 \x01(\t:\x04\xe8\xa0\x1f\x01\"\x1d\n\x1bMsgEditOracleScriptResponse\"&\n\x0bMsgActivate\x12\x11\n\tvalidator\x18\x01 \x01(\t:\x04\xe8\xa0\x1f\x01\"\x15\n\x13MsgActivateResponse\";\n\x0eMsgAddReporter\x12\x11\n\tvalidator\x18\x01 \x01(\t\x12\x10\n\x08reporter\x18\x02 \x01(\t:\x04\xe8\xa0\x1f\x01\"\x18\n\x16MsgAddReporterResponse\">\n\x11MsgRemoveReporter\x12\x11\n\tvalidator\x18\x01 \x01(\t\x12\x10\n\x08reporter\x18\x02 \x01(\t:\x04\xe8\xa0\x1f\x01\"\x1b\n\x19MsgRemoveReporterResponse2\xf3\x05\n\x03Msg\x12K\n\x0bRequestData\x12\x19.oracle.v1.MsgRequestData\x1a!.oracle.v1.MsgRequestDataResponse\x12H\n\nReportData\x12\x18.oracle.v1.MsgReportData\x1a .oracle.v1.MsgReportDataResponse\x12Z\n\x10\x43reateDataSource\x12\x1e.oracle.v1.MsgCreateDataSource\x1a&.oracle.v1.MsgCreateDataSourceResponse\x12T\n\x0e\x45\x64itDataSource\x12\x1c.oracle.v1.MsgEditDataSource\x1a$.oracle.v1.MsgEditDataSourceResponse\x12`\n\x12\x43reateOracleScript\x12 .oracle.v1.MsgCreateOracleScript\x1a(.oracle.v1.MsgCreateOracleScriptResponse\x12Z\n\x10\x45\x64itOracleScript\x12\x1e.oracle.v1.MsgEditOracleScript\x1a&.oracle.v1.MsgEditOracleScriptResponse\x12\x42\n\x08\x41\x63tivate\x12\x16.oracle.v1.MsgActivate\x1a\x1e.oracle.v1.MsgActivateResponse\x12K\n\x0b\x41\x64\x64Reporter\x12\x19.oracle.v1.MsgAddReporter\x1a!.oracle.v1.MsgAddReporterResponse\x12T\n\x0eRemoveReporter\x12\x1c.oracle.v1.MsgRemoveReporter\x1a$.oracle.v1.MsgRemoveReporterResponseB.Z,github.com/bandprotocol/chain/x/oracle/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,oracle_dot_v1_dot_oracle__pb2.DESCRIPTOR,cosmos_dot_base_dot_v1beta1_dot_coin__pb2.DESCRIPTOR,])




_MSGREQUESTDATA = _descriptor.Descriptor(
  name='MsgRequestData',
  full_name='oracle.v1.MsgRequestData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='oracle_script_id', full_name='oracle.v1.MsgRequestData.oracle_script_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\016OracleScriptID\372\336\037\016OracleScriptID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calldata', full_name='oracle.v1.MsgRequestData.calldata', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ask_count', full_name='oracle.v1.MsgRequestData.ask_count', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_count', full_name='oracle.v1.MsgRequestData.min_count', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='oracle.v1.MsgRequestData.client_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\010ClientID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee_limit', full_name='oracle.v1.MsgRequestData.fee_limit', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prepare_gas', full_name='oracle.v1.MsgRequestData.prepare_gas', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execute_gas', full_name='oracle.v1.MsgRequestData.execute_gas', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sender', full_name='oracle.v1.MsgRequestData.sender', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=172,
  serialized_end=501,
)


_MSGREQUESTDATARESPONSE = _descriptor.Descriptor(
  name='MsgRequestDataResponse',
  full_name='oracle.v1.MsgRequestDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=503,
  serialized_end=527,
)


_MSGREPORTDATA = _descriptor.Descriptor(
  name='MsgReportData',
  full_name='oracle.v1.MsgReportData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_id', full_name='oracle.v1.MsgReportData.request_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\tRequestID\372\336\037\tRequestID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_reports', full_name='oracle.v1.MsgReportData.raw_reports', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validator', full_name='oracle.v1.MsgReportData.validator', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reporter', full_name='oracle.v1.MsgReportData.reporter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=530,
  serialized_end=685,
)


_MSGREPORTDATARESPONSE = _descriptor.Descriptor(
  name='MsgReportDataResponse',
  full_name='oracle.v1.MsgReportDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=687,
  serialized_end=710,
)


_MSGCREATEDATASOURCE = _descriptor.Descriptor(
  name='MsgCreateDataSource',
  full_name='oracle.v1.MsgCreateDataSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='oracle.v1.MsgCreateDataSource.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='oracle.v1.MsgCreateDataSource.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='executable', full_name='oracle.v1.MsgCreateDataSource.executable', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee', full_name='oracle.v1.MsgCreateDataSource.fee', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='treasury', full_name='oracle.v1.MsgCreateDataSource.treasury', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner', full_name='oracle.v1.MsgCreateDataSource.owner', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sender', full_name='oracle.v1.MsgCreateDataSource.sender', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=713,
  serialized_end=934,
)


_MSGCREATEDATASOURCERESPONSE = _descriptor.Descriptor(
  name='MsgCreateDataSourceResponse',
  full_name='oracle.v1.MsgCreateDataSourceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=936,
  serialized_end=965,
)


_MSGEDITDATASOURCE = _descriptor.Descriptor(
  name='MsgEditDataSource',
  full_name='oracle.v1.MsgEditDataSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_source_id', full_name='oracle.v1.MsgEditDataSource.data_source_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\014DataSourceID\372\336\037\014DataSourceID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='oracle.v1.MsgEditDataSource.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='oracle.v1.MsgEditDataSource.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='executable', full_name='oracle.v1.MsgEditDataSource.executable', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee', full_name='oracle.v1.MsgEditDataSource.fee', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='treasury', full_name='oracle.v1.MsgEditDataSource.treasury', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner', full_name='oracle.v1.MsgEditDataSource.owner', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sender', full_name='oracle.v1.MsgEditDataSource.sender', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=968,
  serialized_end=1245,
)


_MSGEDITDATASOURCERESPONSE = _descriptor.Descriptor(
  name='MsgEditDataSourceResponse',
  full_name='oracle.v1.MsgEditDataSourceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1247,
  serialized_end=1274,
)


_MSGCREATEORACLESCRIPT = _descriptor.Descriptor(
  name='MsgCreateOracleScript',
  full_name='oracle.v1.MsgCreateOracleScript',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='oracle.v1.MsgCreateOracleScript.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='oracle.v1.MsgCreateOracleScript.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema', full_name='oracle.v1.MsgCreateOracleScript.schema', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_code_url', full_name='oracle.v1.MsgCreateOracleScript.source_code_url', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\rSourceCodeURL', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='oracle.v1.MsgCreateOracleScript.code', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner', full_name='oracle.v1.MsgCreateOracleScript.owner', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sender', full_name='oracle.v1.MsgCreateOracleScript.sender', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1277,
  serialized_end=1446,
)


_MSGCREATEORACLESCRIPTRESPONSE = _descriptor.Descriptor(
  name='MsgCreateOracleScriptResponse',
  full_name='oracle.v1.MsgCreateOracleScriptResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1448,
  serialized_end=1479,
)


_MSGEDITORACLESCRIPT = _descriptor.Descriptor(
  name='MsgEditOracleScript',
  full_name='oracle.v1.MsgEditOracleScript',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='oracle_script_id', full_name='oracle.v1.MsgEditOracleScript.oracle_script_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\016OracleScriptID\372\336\037\016OracleScriptID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='oracle.v1.MsgEditOracleScript.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='oracle.v1.MsgEditOracleScript.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema', full_name='oracle.v1.MsgEditOracleScript.schema', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_code_url', full_name='oracle.v1.MsgEditOracleScript.source_code_url', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\rSourceCodeURL', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='oracle.v1.MsgEditOracleScript.code', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner', full_name='oracle.v1.MsgEditOracleScript.owner', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sender', full_name='oracle.v1.MsgEditOracleScript.sender', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1482,
  serialized_end=1713,
)


_MSGEDITORACLESCRIPTRESPONSE = _descriptor.Descriptor(
  name='MsgEditOracleScriptResponse',
  full_name='oracle.v1.MsgEditOracleScriptResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1715,
  serialized_end=1744,
)


_MSGACTIVATE = _descriptor.Descriptor(
  name='MsgActivate',
  full_name='oracle.v1.MsgActivate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='validator', full_name='oracle.v1.MsgActivate.validator', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1746,
  serialized_end=1784,
)


_MSGACTIVATERESPONSE = _descriptor.Descriptor(
  name='MsgActivateResponse',
  full_name='oracle.v1.MsgActivateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1786,
  serialized_end=1807,
)


_MSGADDREPORTER = _descriptor.Descriptor(
  name='MsgAddReporter',
  full_name='oracle.v1.MsgAddReporter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='validator', full_name='oracle.v1.MsgAddReporter.validator', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reporter', full_name='oracle.v1.MsgAddReporter.reporter', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1809,
  serialized_end=1868,
)


_MSGADDREPORTERRESPONSE = _descriptor.Descriptor(
  name='MsgAddReporterResponse',
  full_name='oracle.v1.MsgAddReporterResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1870,
  serialized_end=1894,
)


_MSGREMOVEREPORTER = _descriptor.Descriptor(
  name='MsgRemoveReporter',
  full_name='oracle.v1.MsgRemoveReporter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='validator', full_name='oracle.v1.MsgRemoveReporter.validator', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reporter', full_name='oracle.v1.MsgRemoveReporter.reporter', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1896,
  serialized_end=1958,
)


_MSGREMOVEREPORTERRESPONSE = _descriptor.Descriptor(
  name='MsgRemoveReporterResponse',
  full_name='oracle.v1.MsgRemoveReporterResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1960,
  serialized_end=1987,
)

_MSGREQUESTDATA.fields_by_name['fee_limit'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_MSGREPORTDATA.fields_by_name['raw_reports'].message_type = oracle_dot_v1_dot_oracle__pb2._RAWREPORT
_MSGCREATEDATASOURCE.fields_by_name['fee'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_MSGEDITDATASOURCE.fields_by_name['fee'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
DESCRIPTOR.message_types_by_name['MsgRequestData'] = _MSGREQUESTDATA
DESCRIPTOR.message_types_by_name['MsgRequestDataResponse'] = _MSGREQUESTDATARESPONSE
DESCRIPTOR.message_types_by_name['MsgReportData'] = _MSGREPORTDATA
DESCRIPTOR.message_types_by_name['MsgReportDataResponse'] = _MSGREPORTDATARESPONSE
DESCRIPTOR.message_types_by_name['MsgCreateDataSource'] = _MSGCREATEDATASOURCE
DESCRIPTOR.message_types_by_name['MsgCreateDataSourceResponse'] = _MSGCREATEDATASOURCERESPONSE
DESCRIPTOR.message_types_by_name['MsgEditDataSource'] = _MSGEDITDATASOURCE
DESCRIPTOR.message_types_by_name['MsgEditDataSourceResponse'] = _MSGEDITDATASOURCERESPONSE
DESCRIPTOR.message_types_by_name['MsgCreateOracleScript'] = _MSGCREATEORACLESCRIPT
DESCRIPTOR.message_types_by_name['MsgCreateOracleScriptResponse'] = _MSGCREATEORACLESCRIPTRESPONSE
DESCRIPTOR.message_types_by_name['MsgEditOracleScript'] = _MSGEDITORACLESCRIPT
DESCRIPTOR.message_types_by_name['MsgEditOracleScriptResponse'] = _MSGEDITORACLESCRIPTRESPONSE
DESCRIPTOR.message_types_by_name['MsgActivate'] = _MSGACTIVATE
DESCRIPTOR.message_types_by_name['MsgActivateResponse'] = _MSGACTIVATERESPONSE
DESCRIPTOR.message_types_by_name['MsgAddReporter'] = _MSGADDREPORTER
DESCRIPTOR.message_types_by_name['MsgAddReporterResponse'] = _MSGADDREPORTERRESPONSE
DESCRIPTOR.message_types_by_name['MsgRemoveReporter'] = _MSGREMOVEREPORTER
DESCRIPTOR.message_types_by_name['MsgRemoveReporterResponse'] = _MSGREMOVEREPORTERRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MsgRequestData = _reflection.GeneratedProtocolMessageType('MsgRequestData', (_message.Message,), {
  'DESCRIPTOR' : _MSGREQUESTDATA,
  '__module__' : 'oracle.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.MsgRequestData)
  })
_sym_db.RegisterMessage(MsgRequestData)

MsgRequestDataResponse = _reflection.GeneratedProtocolMessageType('MsgRequestDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGREQUESTDATARESPONSE,
  '__module__' : 'oracle.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.MsgRequestDataResponse)
  })
_sym_db.RegisterMessage(MsgRequestDataResponse)

MsgReportData = _reflection.GeneratedProtocolMessageType('MsgReportData', (_message.Message,), {
  'DESCRIPTOR' : _MSGREPORTDATA,
  '__module__' : 'oracle.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.MsgReportData)
  })
_sym_db.RegisterMessage(MsgReportData)

MsgReportDataResponse = _reflection.GeneratedProtocolMessageType('MsgReportDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGREPORTDATARESPONSE,
  '__module__' : 'oracle.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.MsgReportDataResponse)
  })
_sym_db.RegisterMessage(MsgReportDataResponse)

MsgCreateDataSource = _reflection.GeneratedProtocolMessageType('MsgCreateDataSource', (_message.Message,), {
  'DESCRIPTOR' : _MSGCREATEDATASOURCE,
  '__module__' : 'oracle.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.MsgCreateDataSource)
  })
_sym_db.RegisterMessage(MsgCreateDataSource)

MsgCreateDataSourceResponse = _reflection.GeneratedProtocolMessageType('MsgCreateDataSourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGCREATEDATASOURCERESPONSE,
  '__module__' : 'oracle.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.MsgCreateDataSourceResponse)
  })
_sym_db.RegisterMessage(MsgCreateDataSourceResponse)

MsgEditDataSource = _reflection.GeneratedProtocolMessageType('MsgEditDataSource', (_message.Message,), {
  'DESCRIPTOR' : _MSGEDITDATASOURCE,
  '__module__' : 'oracle.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.MsgEditDataSource)
  })
_sym_db.RegisterMessage(MsgEditDataSource)

MsgEditDataSourceResponse = _reflection.GeneratedProtocolMessageType('MsgEditDataSourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGEDITDATASOURCERESPONSE,
  '__module__' : 'oracle.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.MsgEditDataSourceResponse)
  })
_sym_db.RegisterMessage(MsgEditDataSourceResponse)

MsgCreateOracleScript = _reflection.GeneratedProtocolMessageType('MsgCreateOracleScript', (_message.Message,), {
  'DESCRIPTOR' : _MSGCREATEORACLESCRIPT,
  '__module__' : 'oracle.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.MsgCreateOracleScript)
  })
_sym_db.RegisterMessage(MsgCreateOracleScript)

MsgCreateOracleScriptResponse = _reflection.GeneratedProtocolMessageType('MsgCreateOracleScriptResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGCREATEORACLESCRIPTRESPONSE,
  '__module__' : 'oracle.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.MsgCreateOracleScriptResponse)
  })
_sym_db.RegisterMessage(MsgCreateOracleScriptResponse)

MsgEditOracleScript = _reflection.GeneratedProtocolMessageType('MsgEditOracleScript', (_message.Message,), {
  'DESCRIPTOR' : _MSGEDITORACLESCRIPT,
  '__module__' : 'oracle.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.MsgEditOracleScript)
  })
_sym_db.RegisterMessage(MsgEditOracleScript)

MsgEditOracleScriptResponse = _reflection.GeneratedProtocolMessageType('MsgEditOracleScriptResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGEDITORACLESCRIPTRESPONSE,
  '__module__' : 'oracle.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.MsgEditOracleScriptResponse)
  })
_sym_db.RegisterMessage(MsgEditOracleScriptResponse)

MsgActivate = _reflection.GeneratedProtocolMessageType('MsgActivate', (_message.Message,), {
  'DESCRIPTOR' : _MSGACTIVATE,
  '__module__' : 'oracle.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.MsgActivate)
  })
_sym_db.RegisterMessage(MsgActivate)

MsgActivateResponse = _reflection.GeneratedProtocolMessageType('MsgActivateResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGACTIVATERESPONSE,
  '__module__' : 'oracle.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.MsgActivateResponse)
  })
_sym_db.RegisterMessage(MsgActivateResponse)

MsgAddReporter = _reflection.GeneratedProtocolMessageType('MsgAddReporter', (_message.Message,), {
  'DESCRIPTOR' : _MSGADDREPORTER,
  '__module__' : 'oracle.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.MsgAddReporter)
  })
_sym_db.RegisterMessage(MsgAddReporter)

MsgAddReporterResponse = _reflection.GeneratedProtocolMessageType('MsgAddReporterResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGADDREPORTERRESPONSE,
  '__module__' : 'oracle.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.MsgAddReporterResponse)
  })
_sym_db.RegisterMessage(MsgAddReporterResponse)

MsgRemoveReporter = _reflection.GeneratedProtocolMessageType('MsgRemoveReporter', (_message.Message,), {
  'DESCRIPTOR' : _MSGREMOVEREPORTER,
  '__module__' : 'oracle.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.MsgRemoveReporter)
  })
_sym_db.RegisterMessage(MsgRemoveReporter)

MsgRemoveReporterResponse = _reflection.GeneratedProtocolMessageType('MsgRemoveReporterResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGREMOVEREPORTERRESPONSE,
  '__module__' : 'oracle.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.MsgRemoveReporterResponse)
  })
_sym_db.RegisterMessage(MsgRemoveReporterResponse)


DESCRIPTOR._options = None
_MSGREQUESTDATA.fields_by_name['oracle_script_id']._options = None
_MSGREQUESTDATA.fields_by_name['client_id']._options = None
_MSGREQUESTDATA.fields_by_name['fee_limit']._options = None
_MSGREQUESTDATA._options = None
_MSGREPORTDATA.fields_by_name['request_id']._options = None
_MSGREPORTDATA.fields_by_name['raw_reports']._options = None
_MSGREPORTDATA._options = None
_MSGCREATEDATASOURCE.fields_by_name['fee']._options = None
_MSGCREATEDATASOURCE._options = None
_MSGEDITDATASOURCE.fields_by_name['data_source_id']._options = None
_MSGEDITDATASOURCE.fields_by_name['fee']._options = None
_MSGEDITDATASOURCE._options = None
_MSGCREATEORACLESCRIPT.fields_by_name['source_code_url']._options = None
_MSGCREATEORACLESCRIPT._options = None
_MSGEDITORACLESCRIPT.fields_by_name['oracle_script_id']._options = None
_MSGEDITORACLESCRIPT.fields_by_name['source_code_url']._options = None
_MSGEDITORACLESCRIPT._options = None
_MSGACTIVATE._options = None
_MSGADDREPORTER._options = None
_MSGREMOVEREPORTER._options = None

_MSG = _descriptor.ServiceDescriptor(
  name='Msg',
  full_name='oracle.v1.Msg',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1990,
  serialized_end=2745,
  methods=[
  _descriptor.MethodDescriptor(
    name='RequestData',
    full_name='oracle.v1.Msg.RequestData',
    index=0,
    containing_service=None,
    input_type=_MSGREQUESTDATA,
    output_type=_MSGREQUESTDATARESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReportData',
    full_name='oracle.v1.Msg.ReportData',
    index=1,
    containing_service=None,
    input_type=_MSGREPORTDATA,
    output_type=_MSGREPORTDATARESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateDataSource',
    full_name='oracle.v1.Msg.CreateDataSource',
    index=2,
    containing_service=None,
    input_type=_MSGCREATEDATASOURCE,
    output_type=_MSGCREATEDATASOURCERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EditDataSource',
    full_name='oracle.v1.Msg.EditDataSource',
    index=3,
    containing_service=None,
    input_type=_MSGEDITDATASOURCE,
    output_type=_MSGEDITDATASOURCERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateOracleScript',
    full_name='oracle.v1.Msg.CreateOracleScript',
    index=4,
    containing_service=None,
    input_type=_MSGCREATEORACLESCRIPT,
    output_type=_MSGCREATEORACLESCRIPTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EditOracleScript',
    full_name='oracle.v1.Msg.EditOracleScript',
    index=5,
    containing_service=None,
    input_type=_MSGEDITORACLESCRIPT,
    output_type=_MSGEDITORACLESCRIPTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Activate',
    full_name='oracle.v1.Msg.Activate',
    index=6,
    containing_service=None,
    input_type=_MSGACTIVATE,
    output_type=_MSGACTIVATERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddReporter',
    full_name='oracle.v1.Msg.AddReporter',
    index=7,
    containing_service=None,
    input_type=_MSGADDREPORTER,
    output_type=_MSGADDREPORTERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveReporter',
    full_name='oracle.v1.Msg.RemoveReporter',
    index=8,
    containing_service=None,
    input_type=_MSGREMOVEREPORTER,
    output_type=_MSGREMOVEREPORTERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MSG)

DESCRIPTOR.services_by_name['Msg'] = _MSG

# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.v1beta1.coin_pb2
import cosmos.gov.v1beta1.gov_pb2
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MsgSubmitProposal(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CONTENT_FIELD_NUMBER: builtins.int
    INITIAL_DEPOSIT_FIELD_NUMBER: builtins.int
    PROPOSER_FIELD_NUMBER: builtins.int
    proposer: typing.Text = ...

    @property
    def content(self) -> google.protobuf.any_pb2.Any: ...

    @property
    def initial_deposit(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...

    def __init__(self,
        *,
        content : typing.Optional[google.protobuf.any_pb2.Any] = ...,
        initial_deposit : typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        proposer : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"content",b"content"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"content",b"content",u"initial_deposit",b"initial_deposit",u"proposer",b"proposer"]) -> None: ...
global___MsgSubmitProposal = MsgSubmitProposal

class MsgSubmitProposalResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PROPOSAL_ID_FIELD_NUMBER: builtins.int
    proposal_id: builtins.int = ...

    def __init__(self,
        *,
        proposal_id : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"proposal_id",b"proposal_id"]) -> None: ...
global___MsgSubmitProposalResponse = MsgSubmitProposalResponse

class MsgVote(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PROPOSAL_ID_FIELD_NUMBER: builtins.int
    VOTER_FIELD_NUMBER: builtins.int
    OPTION_FIELD_NUMBER: builtins.int
    proposal_id: builtins.int = ...
    voter: typing.Text = ...
    option: cosmos.gov.v1beta1.gov_pb2.VoteOption.V = ...

    def __init__(self,
        *,
        proposal_id : builtins.int = ...,
        voter : typing.Text = ...,
        option : cosmos.gov.v1beta1.gov_pb2.VoteOption.V = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"option",b"option",u"proposal_id",b"proposal_id",u"voter",b"voter"]) -> None: ...
global___MsgVote = MsgVote

class MsgVoteResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgVoteResponse = MsgVoteResponse

class MsgDeposit(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PROPOSAL_ID_FIELD_NUMBER: builtins.int
    DEPOSITOR_FIELD_NUMBER: builtins.int
    AMOUNT_FIELD_NUMBER: builtins.int
    proposal_id: builtins.int = ...
    depositor: typing.Text = ...

    @property
    def amount(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...

    def __init__(self,
        *,
        proposal_id : builtins.int = ...,
        depositor : typing.Text = ...,
        amount : typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"amount",b"amount",u"depositor",b"depositor",u"proposal_id",b"proposal_id"]) -> None: ...
global___MsgDeposit = MsgDeposit

class MsgDepositResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgDepositResponse = MsgDepositResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.gov.v1beta1.gov_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GenesisState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    STARTING_PROPOSAL_ID_FIELD_NUMBER: builtins.int
    DEPOSITS_FIELD_NUMBER: builtins.int
    VOTES_FIELD_NUMBER: builtins.int
    PROPOSALS_FIELD_NUMBER: builtins.int
    DEPOSIT_PARAMS_FIELD_NUMBER: builtins.int
    VOTING_PARAMS_FIELD_NUMBER: builtins.int
    TALLY_PARAMS_FIELD_NUMBER: builtins.int
    starting_proposal_id: builtins.int = ...

    @property
    def deposits(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.gov.v1beta1.gov_pb2.Deposit]: ...

    @property
    def votes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.gov.v1beta1.gov_pb2.Vote]: ...

    @property
    def proposals(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.gov.v1beta1.gov_pb2.Proposal]: ...

    @property
    def deposit_params(self) -> cosmos.gov.v1beta1.gov_pb2.DepositParams: ...

    @property
    def voting_params(self) -> cosmos.gov.v1beta1.gov_pb2.VotingParams: ...

    @property
    def tally_params(self) -> cosmos.gov.v1beta1.gov_pb2.TallyParams: ...

    def __init__(self,
        *,
        starting_proposal_id : builtins.int = ...,
        deposits : typing.Optional[typing.Iterable[cosmos.gov.v1beta1.gov_pb2.Deposit]] = ...,
        votes : typing.Optional[typing.Iterable[cosmos.gov.v1beta1.gov_pb2.Vote]] = ...,
        proposals : typing.Optional[typing.Iterable[cosmos.gov.v1beta1.gov_pb2.Proposal]] = ...,
        deposit_params : typing.Optional[cosmos.gov.v1beta1.gov_pb2.DepositParams] = ...,
        voting_params : typing.Optional[cosmos.gov.v1beta1.gov_pb2.VotingParams] = ...,
        tally_params : typing.Optional[cosmos.gov.v1beta1.gov_pb2.TallyParams] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"deposit_params",b"deposit_params",u"tally_params",b"tally_params",u"voting_params",b"voting_params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"deposit_params",b"deposit_params",u"deposits",b"deposits",u"proposals",b"proposals",u"starting_proposal_id",b"starting_proposal_id",u"tally_params",b"tally_params",u"votes",b"votes",u"voting_params",b"voting_params"]) -> None: ...
global___GenesisState = GenesisState



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .query_pb2 import *
class QueryStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    Balance:grpc.UnaryUnaryMultiCallable[
        global___QueryBalanceRequest,
        global___QueryBalanceResponse] = ...

    AllBalances:grpc.UnaryUnaryMultiCallable[
        global___QueryAllBalancesRequest,
        global___QueryAllBalancesResponse] = ...

    TotalSupply:grpc.UnaryUnaryMultiCallable[
        global___QueryTotalSupplyRequest,
        global___QueryTotalSupplyResponse] = ...

    SupplyOf:grpc.UnaryUnaryMultiCallable[
        global___QuerySupplyOfRequest,
        global___QuerySupplyOfResponse] = ...

    Params:grpc.UnaryUnaryMultiCallable[
        global___QueryParamsRequest,
        global___QueryParamsResponse] = ...

    DenomMetadata:grpc.UnaryUnaryMultiCallable[
        global___QueryDenomMetadataRequest,
        global___QueryDenomMetadataResponse] = ...

    DenomsMetadata:grpc.UnaryUnaryMultiCallable[
        global___QueryDenomsMetadataRequest,
        global___QueryDenomsMetadataResponse] = ...


class QueryServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Balance(self,
        request: global___QueryBalanceRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryBalanceResponse: ...

    @abc.abstractmethod
    def AllBalances(self,
        request: global___QueryAllBalancesRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryAllBalancesResponse: ...

    @abc.abstractmethod
    def TotalSupply(self,
        request: global___QueryTotalSupplyRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryTotalSupplyResponse: ...

    @abc.abstractmethod
    def SupplyOf(self,
        request: global___QuerySupplyOfRequest,
        context: grpc.ServicerContext,
    ) -> global___QuerySupplyOfResponse: ...

    @abc.abstractmethod
    def Params(self,
        request: global___QueryParamsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryParamsResponse: ...

    @abc.abstractmethod
    def DenomMetadata(self,
        request: global___QueryDenomMetadataRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryDenomMetadataResponse: ...

    @abc.abstractmethod
    def DenomsMetadata(self,
        request: global___QueryDenomsMetadataRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryDenomsMetadataResponse: ...


def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...



class PybandError(Exception):
    pass


class EmptyRequestMsgError(PybandError):
    pass


class QueryError(PybandError):
    pass


class NegativeIntegerError(PybandError):
    pass


class ValueTooLargeError(PybandError):
    pass


class InsufficientCoinError(PybandError):
    pass


class EmptyMsgError(PybandError):
    pass


class NotFoundError(PybandError):
    pass


class UndefinedError(PybandError):
    pass


class DecodeError(PybandError):
    pass


class ConvertError(PybandError):
    pass


class UnsuccessfulCallError(PybandError):
    pass


class CreateError(PybandError):
    pass


class SchemaError(PybandError):
    pass



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import ibc.core.client.v1.client_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class State(metaclass=_State):
    V = typing.NewType('V', builtins.int)

global___State = State

STATE_UNINITIALIZED_UNSPECIFIED = State.V(0)
STATE_INIT = State.V(1)
STATE_TRYOPEN = State.V(2)
STATE_OPEN = State.V(3)
STATE_CLOSED = State.V(4)

class _State(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[State.V], builtins.type):  # type: ignore
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    STATE_UNINITIALIZED_UNSPECIFIED = State.V(0)
    STATE_INIT = State.V(1)
    STATE_TRYOPEN = State.V(2)
    STATE_OPEN = State.V(3)
    STATE_CLOSED = State.V(4)

class Order(metaclass=_Order):
    V = typing.NewType('V', builtins.int)

global___Order = Order

ORDER_NONE_UNSPECIFIED = Order.V(0)
ORDER_UNORDERED = Order.V(1)
ORDER_ORDERED = Order.V(2)

class _Order(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Order.V], builtins.type):  # type: ignore
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    ORDER_NONE_UNSPECIFIED = Order.V(0)
    ORDER_UNORDERED = Order.V(1)
    ORDER_ORDERED = Order.V(2)

class Channel(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    STATE_FIELD_NUMBER: builtins.int
    ORDERING_FIELD_NUMBER: builtins.int
    COUNTERPARTY_FIELD_NUMBER: builtins.int
    CONNECTION_HOPS_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    state: global___State.V = ...
    ordering: global___Order.V = ...

    @property
    def connection_hops(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    version: typing.Text = ...

    @property
    def counterparty(self) -> global___Counterparty: ...

    def __init__(self,
        *,
        state : global___State.V = ...,
        ordering : global___Order.V = ...,
        counterparty : typing.Optional[global___Counterparty] = ...,
        connection_hops : typing.Optional[typing.Iterable[typing.Text]] = ...,
        version : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"counterparty",b"counterparty"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"connection_hops",b"connection_hops",u"counterparty",b"counterparty",u"ordering",b"ordering",u"state",b"state",u"version",b"version"]) -> None: ...
global___Channel = Channel

class IdentifiedChannel(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    STATE_FIELD_NUMBER: builtins.int
    ORDERING_FIELD_NUMBER: builtins.int
    COUNTERPARTY_FIELD_NUMBER: builtins.int
    CONNECTION_HOPS_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    PORT_ID_FIELD_NUMBER: builtins.int
    CHANNEL_ID_FIELD_NUMBER: builtins.int
    state: global___State.V = ...
    ordering: global___Order.V = ...

    @property
    def connection_hops(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    version: typing.Text = ...
    port_id: typing.Text = ...
    channel_id: typing.Text = ...

    @property
    def counterparty(self) -> global___Counterparty: ...

    def __init__(self,
        *,
        state : global___State.V = ...,
        ordering : global___Order.V = ...,
        counterparty : typing.Optional[global___Counterparty] = ...,
        connection_hops : typing.Optional[typing.Iterable[typing.Text]] = ...,
        version : typing.Text = ...,
        port_id : typing.Text = ...,
        channel_id : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"counterparty",b"counterparty"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"channel_id",b"channel_id",u"connection_hops",b"connection_hops",u"counterparty",b"counterparty",u"ordering",b"ordering",u"port_id",b"port_id",u"state",b"state",u"version",b"version"]) -> None: ...
global___IdentifiedChannel = IdentifiedChannel

class Counterparty(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PORT_ID_FIELD_NUMBER: builtins.int
    CHANNEL_ID_FIELD_NUMBER: builtins.int
    port_id: typing.Text = ...
    channel_id: typing.Text = ...

    def __init__(self,
        *,
        port_id : typing.Text = ...,
        channel_id : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"channel_id",b"channel_id",u"port_id",b"port_id"]) -> None: ...
global___Counterparty = Counterparty

class Packet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SEQUENCE_FIELD_NUMBER: builtins.int
    SOURCE_PORT_FIELD_NUMBER: builtins.int
    SOURCE_CHANNEL_FIELD_NUMBER: builtins.int
    DESTINATION_PORT_FIELD_NUMBER: builtins.int
    DESTINATION_CHANNEL_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    TIMEOUT_HEIGHT_FIELD_NUMBER: builtins.int
    TIMEOUT_TIMESTAMP_FIELD_NUMBER: builtins.int
    sequence: builtins.int = ...
    source_port: typing.Text = ...
    source_channel: typing.Text = ...
    destination_port: typing.Text = ...
    destination_channel: typing.Text = ...
    data: builtins.bytes = ...
    timeout_timestamp: builtins.int = ...

    @property
    def timeout_height(self) -> ibc.core.client.v1.client_pb2.Height: ...

    def __init__(self,
        *,
        sequence : builtins.int = ...,
        source_port : typing.Text = ...,
        source_channel : typing.Text = ...,
        destination_port : typing.Text = ...,
        destination_channel : typing.Text = ...,
        data : builtins.bytes = ...,
        timeout_height : typing.Optional[ibc.core.client.v1.client_pb2.Height] = ...,
        timeout_timestamp : builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"timeout_height",b"timeout_height"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"data",b"data",u"destination_channel",b"destination_channel",u"destination_port",b"destination_port",u"sequence",b"sequence",u"source_channel",b"source_channel",u"source_port",b"source_port",u"timeout_height",b"timeout_height",u"timeout_timestamp",b"timeout_timestamp"]) -> None: ...
global___Packet = Packet

class PacketState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PORT_ID_FIELD_NUMBER: builtins.int
    CHANNEL_ID_FIELD_NUMBER: builtins.int
    SEQUENCE_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    port_id: typing.Text = ...
    channel_id: typing.Text = ...
    sequence: builtins.int = ...
    data: builtins.bytes = ...

    def __init__(self,
        *,
        port_id : typing.Text = ...,
        channel_id : typing.Text = ...,
        sequence : builtins.int = ...,
        data : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"channel_id",b"channel_id",u"data",b"data",u"port_id",b"port_id",u"sequence",b"sequence"]) -> None: ...
global___PacketState = PacketState

class Acknowledgement(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESULT_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    result: builtins.bytes = ...
    error: typing.Text = ...

    def __init__(self,
        *,
        result : builtins.bytes = ...,
        error : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"error",b"error",u"response",b"response",u"result",b"result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"error",b"error",u"response",b"response",u"result",b"result"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"response",b"response"]) -> typing.Optional[typing_extensions.Literal["result","error"]]: ...
global___Acknowledgement = Acknowledgement



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ValidatorSigningInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ADDRESS_FIELD_NUMBER: builtins.int
    START_HEIGHT_FIELD_NUMBER: builtins.int
    INDEX_OFFSET_FIELD_NUMBER: builtins.int
    JAILED_UNTIL_FIELD_NUMBER: builtins.int
    TOMBSTONED_FIELD_NUMBER: builtins.int
    MISSED_BLOCKS_COUNTER_FIELD_NUMBER: builtins.int
    address: typing.Text = ...
    start_height: builtins.int = ...
    index_offset: builtins.int = ...
    tombstoned: builtins.bool = ...
    missed_blocks_counter: builtins.int = ...

    @property
    def jailed_until(self) -> google.protobuf.timestamp_pb2.Timestamp: ...

    def __init__(self,
        *,
        address : typing.Text = ...,
        start_height : builtins.int = ...,
        index_offset : builtins.int = ...,
        jailed_until : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        tombstoned : builtins.bool = ...,
        missed_blocks_counter : builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"jailed_until",b"jailed_until"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"address",b"address",u"index_offset",b"index_offset",u"jailed_until",b"jailed_until",u"missed_blocks_counter",b"missed_blocks_counter",u"start_height",b"start_height",u"tombstoned",b"tombstoned"]) -> None: ...
global___ValidatorSigningInfo = ValidatorSigningInfo

class Params(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SIGNED_BLOCKS_WINDOW_FIELD_NUMBER: builtins.int
    MIN_SIGNED_PER_WINDOW_FIELD_NUMBER: builtins.int
    DOWNTIME_JAIL_DURATION_FIELD_NUMBER: builtins.int
    SLASH_FRACTION_DOUBLE_SIGN_FIELD_NUMBER: builtins.int
    SLASH_FRACTION_DOWNTIME_FIELD_NUMBER: builtins.int
    signed_blocks_window: builtins.int = ...
    min_signed_per_window: builtins.bytes = ...
    slash_fraction_double_sign: builtins.bytes = ...
    slash_fraction_downtime: builtins.bytes = ...

    @property
    def downtime_jail_duration(self) -> google.protobuf.duration_pb2.Duration: ...

    def __init__(self,
        *,
        signed_blocks_window : builtins.int = ...,
        min_signed_per_window : builtins.bytes = ...,
        downtime_jail_duration : typing.Optional[google.protobuf.duration_pb2.Duration] = ...,
        slash_fraction_double_sign : builtins.bytes = ...,
        slash_fraction_downtime : builtins.bytes = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"downtime_jail_duration",b"downtime_jail_duration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"downtime_jail_duration",b"downtime_jail_duration",u"min_signed_per_window",b"min_signed_per_window",u"signed_blocks_window",b"signed_blocks_window",u"slash_fraction_double_sign",b"slash_fraction_double_sign",u"slash_fraction_downtime",b"slash_fraction_downtime"]) -> None: ...
global___Params = Params



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import oracle.v1.oracle_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MsgRequestData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ORACLE_SCRIPT_ID_FIELD_NUMBER: builtins.int
    CALLDATA_FIELD_NUMBER: builtins.int
    ASK_COUNT_FIELD_NUMBER: builtins.int
    MIN_COUNT_FIELD_NUMBER: builtins.int
    CLIENT_ID_FIELD_NUMBER: builtins.int
    FEE_LIMIT_FIELD_NUMBER: builtins.int
    PREPARE_GAS_FIELD_NUMBER: builtins.int
    EXECUTE_GAS_FIELD_NUMBER: builtins.int
    SENDER_FIELD_NUMBER: builtins.int
    oracle_script_id: builtins.int = ...
    calldata: builtins.bytes = ...
    ask_count: builtins.int = ...
    min_count: builtins.int = ...
    client_id: typing.Text = ...
    prepare_gas: builtins.int = ...
    execute_gas: builtins.int = ...
    sender: typing.Text = ...

    @property
    def fee_limit(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...

    def __init__(self,
        *,
        oracle_script_id : builtins.int = ...,
        calldata : builtins.bytes = ...,
        ask_count : builtins.int = ...,
        min_count : builtins.int = ...,
        client_id : typing.Text = ...,
        fee_limit : typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        prepare_gas : builtins.int = ...,
        execute_gas : builtins.int = ...,
        sender : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"ask_count",b"ask_count",u"calldata",b"calldata",u"client_id",b"client_id",u"execute_gas",b"execute_gas",u"fee_limit",b"fee_limit",u"min_count",b"min_count",u"oracle_script_id",b"oracle_script_id",u"prepare_gas",b"prepare_gas",u"sender",b"sender"]) -> None: ...
global___MsgRequestData = MsgRequestData

class MsgRequestDataResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgRequestDataResponse = MsgRequestDataResponse

class MsgReportData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    REQUEST_ID_FIELD_NUMBER: builtins.int
    RAW_REPORTS_FIELD_NUMBER: builtins.int
    VALIDATOR_FIELD_NUMBER: builtins.int
    REPORTER_FIELD_NUMBER: builtins.int
    request_id: builtins.int = ...
    validator: typing.Text = ...
    reporter: typing.Text = ...

    @property
    def raw_reports(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[oracle.v1.oracle_pb2.RawReport]: ...

    def __init__(self,
        *,
        request_id : builtins.int = ...,
        raw_reports : typing.Optional[typing.Iterable[oracle.v1.oracle_pb2.RawReport]] = ...,
        validator : typing.Text = ...,
        reporter : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"raw_reports",b"raw_reports",u"reporter",b"reporter",u"request_id",b"request_id",u"validator",b"validator"]) -> None: ...
global___MsgReportData = MsgReportData

class MsgReportDataResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgReportDataResponse = MsgReportDataResponse

class MsgCreateDataSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXECUTABLE_FIELD_NUMBER: builtins.int
    FEE_FIELD_NUMBER: builtins.int
    TREASURY_FIELD_NUMBER: builtins.int
    OWNER_FIELD_NUMBER: builtins.int
    SENDER_FIELD_NUMBER: builtins.int
    name: typing.Text = ...
    description: typing.Text = ...
    executable: builtins.bytes = ...
    treasury: typing.Text = ...
    owner: typing.Text = ...
    sender: typing.Text = ...

    @property
    def fee(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...

    def __init__(self,
        *,
        name : typing.Text = ...,
        description : typing.Text = ...,
        executable : builtins.bytes = ...,
        fee : typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        treasury : typing.Text = ...,
        owner : typing.Text = ...,
        sender : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"description",b"description",u"executable",b"executable",u"fee",b"fee",u"name",b"name",u"owner",b"owner",u"sender",b"sender",u"treasury",b"treasury"]) -> None: ...
global___MsgCreateDataSource = MsgCreateDataSource

class MsgCreateDataSourceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgCreateDataSourceResponse = MsgCreateDataSourceResponse

class MsgEditDataSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_SOURCE_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXECUTABLE_FIELD_NUMBER: builtins.int
    FEE_FIELD_NUMBER: builtins.int
    TREASURY_FIELD_NUMBER: builtins.int
    OWNER_FIELD_NUMBER: builtins.int
    SENDER_FIELD_NUMBER: builtins.int
    data_source_id: builtins.int = ...
    name: typing.Text = ...
    description: typing.Text = ...
    executable: builtins.bytes = ...
    treasury: typing.Text = ...
    owner: typing.Text = ...
    sender: typing.Text = ...

    @property
    def fee(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...

    def __init__(self,
        *,
        data_source_id : builtins.int = ...,
        name : typing.Text = ...,
        description : typing.Text = ...,
        executable : builtins.bytes = ...,
        fee : typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        treasury : typing.Text = ...,
        owner : typing.Text = ...,
        sender : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"data_source_id",b"data_source_id",u"description",b"description",u"executable",b"executable",u"fee",b"fee",u"name",b"name",u"owner",b"owner",u"sender",b"sender",u"treasury",b"treasury"]) -> None: ...
global___MsgEditDataSource = MsgEditDataSource

class MsgEditDataSourceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgEditDataSourceResponse = MsgEditDataSourceResponse

class MsgCreateOracleScript(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    SOURCE_CODE_URL_FIELD_NUMBER: builtins.int
    CODE_FIELD_NUMBER: builtins.int
    OWNER_FIELD_NUMBER: builtins.int
    SENDER_FIELD_NUMBER: builtins.int
    name: typing.Text = ...
    description: typing.Text = ...
    schema: typing.Text = ...
    source_code_url: typing.Text = ...
    code: builtins.bytes = ...
    owner: typing.Text = ...
    sender: typing.Text = ...

    def __init__(self,
        *,
        name : typing.Text = ...,
        description : typing.Text = ...,
        schema : typing.Text = ...,
        source_code_url : typing.Text = ...,
        code : builtins.bytes = ...,
        owner : typing.Text = ...,
        sender : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"code",b"code",u"description",b"description",u"name",b"name",u"owner",b"owner",u"schema",b"schema",u"sender",b"sender",u"source_code_url",b"source_code_url"]) -> None: ...
global___MsgCreateOracleScript = MsgCreateOracleScript

class MsgCreateOracleScriptResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgCreateOracleScriptResponse = MsgCreateOracleScriptResponse

class MsgEditOracleScript(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ORACLE_SCRIPT_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    SOURCE_CODE_URL_FIELD_NUMBER: builtins.int
    CODE_FIELD_NUMBER: builtins.int
    OWNER_FIELD_NUMBER: builtins.int
    SENDER_FIELD_NUMBER: builtins.int
    oracle_script_id: builtins.int = ...
    name: typing.Text = ...
    description: typing.Text = ...
    schema: typing.Text = ...
    source_code_url: typing.Text = ...
    code: builtins.bytes = ...
    owner: typing.Text = ...
    sender: typing.Text = ...

    def __init__(self,
        *,
        oracle_script_id : builtins.int = ...,
        name : typing.Text = ...,
        description : typing.Text = ...,
        schema : typing.Text = ...,
        source_code_url : typing.Text = ...,
        code : builtins.bytes = ...,
        owner : typing.Text = ...,
        sender : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"code",b"code",u"description",b"description",u"name",b"name",u"oracle_script_id",b"oracle_script_id",u"owner",b"owner",u"schema",b"schema",u"sender",b"sender",u"source_code_url",b"source_code_url"]) -> None: ...
global___MsgEditOracleScript = MsgEditOracleScript

class MsgEditOracleScriptResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgEditOracleScriptResponse = MsgEditOracleScriptResponse

class MsgActivate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALIDATOR_FIELD_NUMBER: builtins.int
    validator: typing.Text = ...

    def __init__(self,
        *,
        validator : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"validator",b"validator"]) -> None: ...
global___MsgActivate = MsgActivate

class MsgActivateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgActivateResponse = MsgActivateResponse

class MsgAddReporter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALIDATOR_FIELD_NUMBER: builtins.int
    REPORTER_FIELD_NUMBER: builtins.int
    validator: typing.Text = ...
    reporter: typing.Text = ...

    def __init__(self,
        *,
        validator : typing.Text = ...,
        reporter : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"reporter",b"reporter",u"validator",b"validator"]) -> None: ...
global___MsgAddReporter = MsgAddReporter

class MsgAddReporterResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgAddReporterResponse = MsgAddReporterResponse

class MsgRemoveReporter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALIDATOR_FIELD_NUMBER: builtins.int
    REPORTER_FIELD_NUMBER: builtins.int
    validator: typing.Text = ...
    reporter: typing.Text = ...

    def __init__(self,
        *,
        validator : typing.Text = ...,
        reporter : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"reporter",b"reporter",u"validator",b"validator"]) -> None: ...
global___MsgRemoveReporter = MsgRemoveReporter

class MsgRemoveReporterResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgRemoveReporterResponse = MsgRemoveReporterResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class HttpBody(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CONTENT_TYPE_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    EXTENSIONS_FIELD_NUMBER: builtins.int
    content_type: typing.Text = ...
    data: builtins.bytes = ...

    @property
    def extensions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.any_pb2.Any]: ...

    def __init__(self,
        *,
        content_type : typing.Text = ...,
        data : builtins.bytes = ...,
        extensions : typing.Optional[typing.Iterable[google.protobuf.any_pb2.Any]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"content_type",b"content_type",u"data",b"data",u"extensions",b"extensions"]) -> None: ...
global___HttpBody = HttpBody



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import ibc.core.client.v1.client_pb2
import ibc.core.connection.v1.connection_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MsgConnectionOpenInit(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CLIENT_ID_FIELD_NUMBER: builtins.int
    COUNTERPARTY_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    DELAY_PERIOD_FIELD_NUMBER: builtins.int
    SIGNER_FIELD_NUMBER: builtins.int
    client_id: typing.Text = ...
    delay_period: builtins.int = ...
    signer: typing.Text = ...

    @property
    def counterparty(self) -> ibc.core.connection.v1.connection_pb2.Counterparty: ...

    @property
    def version(self) -> ibc.core.connection.v1.connection_pb2.Version: ...

    def __init__(self,
        *,
        client_id : typing.Text = ...,
        counterparty : typing.Optional[ibc.core.connection.v1.connection_pb2.Counterparty] = ...,
        version : typing.Optional[ibc.core.connection.v1.connection_pb2.Version] = ...,
        delay_period : builtins.int = ...,
        signer : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"counterparty",b"counterparty",u"version",b"version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"client_id",b"client_id",u"counterparty",b"counterparty",u"delay_period",b"delay_period",u"signer",b"signer",u"version",b"version"]) -> None: ...
global___MsgConnectionOpenInit = MsgConnectionOpenInit

class MsgConnectionOpenInitResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgConnectionOpenInitResponse = MsgConnectionOpenInitResponse

class MsgConnectionOpenTry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CLIENT_ID_FIELD_NUMBER: builtins.int
    PREVIOUS_CONNECTION_ID_FIELD_NUMBER: builtins.int
    CLIENT_STATE_FIELD_NUMBER: builtins.int
    COUNTERPARTY_FIELD_NUMBER: builtins.int
    DELAY_PERIOD_FIELD_NUMBER: builtins.int
    COUNTERPARTY_VERSIONS_FIELD_NUMBER: builtins.int
    PROOF_HEIGHT_FIELD_NUMBER: builtins.int
    PROOF_INIT_FIELD_NUMBER: builtins.int
    PROOF_CLIENT_FIELD_NUMBER: builtins.int
    PROOF_CONSENSUS_FIELD_NUMBER: builtins.int
    CONSENSUS_HEIGHT_FIELD_NUMBER: builtins.int
    SIGNER_FIELD_NUMBER: builtins.int
    client_id: typing.Text = ...
    previous_connection_id: typing.Text = ...
    delay_period: builtins.int = ...
    proof_init: builtins.bytes = ...
    proof_client: builtins.bytes = ...
    proof_consensus: builtins.bytes = ...
    signer: typing.Text = ...

    @property
    def client_state(self) -> google.protobuf.any_pb2.Any: ...

    @property
    def counterparty(self) -> ibc.core.connection.v1.connection_pb2.Counterparty: ...

    @property
    def counterparty_versions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[ibc.core.connection.v1.connection_pb2.Version]: ...

    @property
    def proof_height(self) -> ibc.core.client.v1.client_pb2.Height: ...

    @property
    def consensus_height(self) -> ibc.core.client.v1.client_pb2.Height: ...

    def __init__(self,
        *,
        client_id : typing.Text = ...,
        previous_connection_id : typing.Text = ...,
        client_state : typing.Optional[google.protobuf.any_pb2.Any] = ...,
        counterparty : typing.Optional[ibc.core.connection.v1.connection_pb2.Counterparty] = ...,
        delay_period : builtins.int = ...,
        counterparty_versions : typing.Optional[typing.Iterable[ibc.core.connection.v1.connection_pb2.Version]] = ...,
        proof_height : typing.Optional[ibc.core.client.v1.client_pb2.Height] = ...,
        proof_init : builtins.bytes = ...,
        proof_client : builtins.bytes = ...,
        proof_consensus : builtins.bytes = ...,
        consensus_height : typing.Optional[ibc.core.client.v1.client_pb2.Height] = ...,
        signer : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"client_state",b"client_state",u"consensus_height",b"consensus_height",u"counterparty",b"counterparty",u"proof_height",b"proof_height"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"client_id",b"client_id",u"client_state",b"client_state",u"consensus_height",b"consensus_height",u"counterparty",b"counterparty",u"counterparty_versions",b"counterparty_versions",u"delay_period",b"delay_period",u"previous_connection_id",b"previous_connection_id",u"proof_client",b"proof_client",u"proof_consensus",b"proof_consensus",u"proof_height",b"proof_height",u"proof_init",b"proof_init",u"signer",b"signer"]) -> None: ...
global___MsgConnectionOpenTry = MsgConnectionOpenTry

class MsgConnectionOpenTryResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgConnectionOpenTryResponse = MsgConnectionOpenTryResponse

class MsgConnectionOpenAck(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CONNECTION_ID_FIELD_NUMBER: builtins.int
    COUNTERPARTY_CONNECTION_ID_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    CLIENT_STATE_FIELD_NUMBER: builtins.int
    PROOF_HEIGHT_FIELD_NUMBER: builtins.int
    PROOF_TRY_FIELD_NUMBER: builtins.int
    PROOF_CLIENT_FIELD_NUMBER: builtins.int
    PROOF_CONSENSUS_FIELD_NUMBER: builtins.int
    CONSENSUS_HEIGHT_FIELD_NUMBER: builtins.int
    SIGNER_FIELD_NUMBER: builtins.int
    connection_id: typing.Text = ...
    counterparty_connection_id: typing.Text = ...
    proof_try: builtins.bytes = ...
    proof_client: builtins.bytes = ...
    proof_consensus: builtins.bytes = ...
    signer: typing.Text = ...

    @property
    def version(self) -> ibc.core.connection.v1.connection_pb2.Version: ...

    @property
    def client_state(self) -> google.protobuf.any_pb2.Any: ...

    @property
    def proof_height(self) -> ibc.core.client.v1.client_pb2.Height: ...

    @property
    def consensus_height(self) -> ibc.core.client.v1.client_pb2.Height: ...

    def __init__(self,
        *,
        connection_id : typing.Text = ...,
        counterparty_connection_id : typing.Text = ...,
        version : typing.Optional[ibc.core.connection.v1.connection_pb2.Version] = ...,
        client_state : typing.Optional[google.protobuf.any_pb2.Any] = ...,
        proof_height : typing.Optional[ibc.core.client.v1.client_pb2.Height] = ...,
        proof_try : builtins.bytes = ...,
        proof_client : builtins.bytes = ...,
        proof_consensus : builtins.bytes = ...,
        consensus_height : typing.Optional[ibc.core.client.v1.client_pb2.Height] = ...,
        signer : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"client_state",b"client_state",u"consensus_height",b"consensus_height",u"proof_height",b"proof_height",u"version",b"version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"client_state",b"client_state",u"connection_id",b"connection_id",u"consensus_height",b"consensus_height",u"counterparty_connection_id",b"counterparty_connection_id",u"proof_client",b"proof_client",u"proof_consensus",b"proof_consensus",u"proof_height",b"proof_height",u"proof_try",b"proof_try",u"signer",b"signer",u"version",b"version"]) -> None: ...
global___MsgConnectionOpenAck = MsgConnectionOpenAck

class MsgConnectionOpenAckResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgConnectionOpenAckResponse = MsgConnectionOpenAckResponse

class MsgConnectionOpenConfirm(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CONNECTION_ID_FIELD_NUMBER: builtins.int
    PROOF_ACK_FIELD_NUMBER: builtins.int
    PROOF_HEIGHT_FIELD_NUMBER: builtins.int
    SIGNER_FIELD_NUMBER: builtins.int
    connection_id: typing.Text = ...
    proof_ack: builtins.bytes = ...
    signer: typing.Text = ...

    @property
    def proof_height(self) -> ibc.core.client.v1.client_pb2.Height: ...

    def __init__(self,
        *,
        connection_id : typing.Text = ...,
        proof_ack : builtins.bytes = ...,
        proof_height : typing.Optional[ibc.core.client.v1.client_pb2.Height] = ...,
        signer : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"proof_height",b"proof_height"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"connection_id",b"connection_id",u"proof_ack",b"proof_ack",u"proof_height",b"proof_height",u"signer",b"signer"]) -> None: ...
global___MsgConnectionOpenConfirm = MsgConnectionOpenConfirm

class MsgConnectionOpenConfirmResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgConnectionOpenConfirmResponse = MsgConnectionOpenConfirmResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class HashOp(metaclass=_HashOp):
    V = typing.NewType('V', builtins.int)

global___HashOp = HashOp

NO_HASH = HashOp.V(0)
SHA256 = HashOp.V(1)
SHA512 = HashOp.V(2)
KECCAK = HashOp.V(3)
RIPEMD160 = HashOp.V(4)
BITCOIN = HashOp.V(5)

class _HashOp(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[HashOp.V], builtins.type):  # type: ignore
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    NO_HASH = HashOp.V(0)
    SHA256 = HashOp.V(1)
    SHA512 = HashOp.V(2)
    KECCAK = HashOp.V(3)
    RIPEMD160 = HashOp.V(4)
    BITCOIN = HashOp.V(5)

class LengthOp(metaclass=_LengthOp):
    V = typing.NewType('V', builtins.int)

global___LengthOp = LengthOp

NO_PREFIX = LengthOp.V(0)
VAR_PROTO = LengthOp.V(1)
VAR_RLP = LengthOp.V(2)
FIXED32_BIG = LengthOp.V(3)
FIXED32_LITTLE = LengthOp.V(4)
FIXED64_BIG = LengthOp.V(5)
FIXED64_LITTLE = LengthOp.V(6)
REQUIRE_32_BYTES = LengthOp.V(7)
REQUIRE_64_BYTES = LengthOp.V(8)

class _LengthOp(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[LengthOp.V], builtins.type):  # type: ignore
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    NO_PREFIX = LengthOp.V(0)
    VAR_PROTO = LengthOp.V(1)
    VAR_RLP = LengthOp.V(2)
    FIXED32_BIG = LengthOp.V(3)
    FIXED32_LITTLE = LengthOp.V(4)
    FIXED64_BIG = LengthOp.V(5)
    FIXED64_LITTLE = LengthOp.V(6)
    REQUIRE_32_BYTES = LengthOp.V(7)
    REQUIRE_64_BYTES = LengthOp.V(8)

class ExistenceProof(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    LEAF_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    key: builtins.bytes = ...
    value: builtins.bytes = ...

    @property
    def leaf(self) -> global___LeafOp: ...

    @property
    def path(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InnerOp]: ...

    def __init__(self,
        *,
        key : builtins.bytes = ...,
        value : builtins.bytes = ...,
        leaf : typing.Optional[global___LeafOp] = ...,
        path : typing.Optional[typing.Iterable[global___InnerOp]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"leaf",b"leaf"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"key",b"key",u"leaf",b"leaf",u"path",b"path",u"value",b"value"]) -> None: ...
global___ExistenceProof = ExistenceProof

class NonExistenceProof(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    KEY_FIELD_NUMBER: builtins.int
    LEFT_FIELD_NUMBER: builtins.int
    RIGHT_FIELD_NUMBER: builtins.int
    key: builtins.bytes = ...

    @property
    def left(self) -> global___ExistenceProof: ...

    @property
    def right(self) -> global___ExistenceProof: ...

    def __init__(self,
        *,
        key : builtins.bytes = ...,
        left : typing.Optional[global___ExistenceProof] = ...,
        right : typing.Optional[global___ExistenceProof] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"left",b"left",u"right",b"right"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"key",b"key",u"left",b"left",u"right",b"right"]) -> None: ...
global___NonExistenceProof = NonExistenceProof

class CommitmentProof(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    EXIST_FIELD_NUMBER: builtins.int
    NONEXIST_FIELD_NUMBER: builtins.int
    BATCH_FIELD_NUMBER: builtins.int
    COMPRESSED_FIELD_NUMBER: builtins.int

    @property
    def exist(self) -> global___ExistenceProof: ...

    @property
    def nonexist(self) -> global___NonExistenceProof: ...

    @property
    def batch(self) -> global___BatchProof: ...

    @property
    def compressed(self) -> global___CompressedBatchProof: ...

    def __init__(self,
        *,
        exist : typing.Optional[global___ExistenceProof] = ...,
        nonexist : typing.Optional[global___NonExistenceProof] = ...,
        batch : typing.Optional[global___BatchProof] = ...,
        compressed : typing.Optional[global___CompressedBatchProof] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"batch",b"batch",u"compressed",b"compressed",u"exist",b"exist",u"nonexist",b"nonexist",u"proof",b"proof"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"batch",b"batch",u"compressed",b"compressed",u"exist",b"exist",u"nonexist",b"nonexist",u"proof",b"proof"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"proof",b"proof"]) -> typing.Optional[typing_extensions.Literal["exist","nonexist","batch","compressed"]]: ...
global___CommitmentProof = CommitmentProof

class LeafOp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HASH_FIELD_NUMBER: builtins.int
    PREHASH_KEY_FIELD_NUMBER: builtins.int
    PREHASH_VALUE_FIELD_NUMBER: builtins.int
    LENGTH_FIELD_NUMBER: builtins.int
    PREFIX_FIELD_NUMBER: builtins.int
    hash: global___HashOp.V = ...
    prehash_key: global___HashOp.V = ...
    prehash_value: global___HashOp.V = ...
    length: global___LengthOp.V = ...
    prefix: builtins.bytes = ...

    def __init__(self,
        *,
        hash : global___HashOp.V = ...,
        prehash_key : global___HashOp.V = ...,
        prehash_value : global___HashOp.V = ...,
        length : global___LengthOp.V = ...,
        prefix : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"hash",b"hash",u"length",b"length",u"prefix",b"prefix",u"prehash_key",b"prehash_key",u"prehash_value",b"prehash_value"]) -> None: ...
global___LeafOp = LeafOp

class InnerOp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HASH_FIELD_NUMBER: builtins.int
    PREFIX_FIELD_NUMBER: builtins.int
    SUFFIX_FIELD_NUMBER: builtins.int
    hash: global___HashOp.V = ...
    prefix: builtins.bytes = ...
    suffix: builtins.bytes = ...

    def __init__(self,
        *,
        hash : global___HashOp.V = ...,
        prefix : builtins.bytes = ...,
        suffix : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"hash",b"hash",u"prefix",b"prefix",u"suffix",b"suffix"]) -> None: ...
global___InnerOp = InnerOp

class ProofSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    LEAF_SPEC_FIELD_NUMBER: builtins.int
    INNER_SPEC_FIELD_NUMBER: builtins.int
    MAX_DEPTH_FIELD_NUMBER: builtins.int
    MIN_DEPTH_FIELD_NUMBER: builtins.int
    max_depth: builtins.int = ...
    min_depth: builtins.int = ...

    @property
    def leaf_spec(self) -> global___LeafOp: ...

    @property
    def inner_spec(self) -> global___InnerSpec: ...

    def __init__(self,
        *,
        leaf_spec : typing.Optional[global___LeafOp] = ...,
        inner_spec : typing.Optional[global___InnerSpec] = ...,
        max_depth : builtins.int = ...,
        min_depth : builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"inner_spec",b"inner_spec",u"leaf_spec",b"leaf_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"inner_spec",b"inner_spec",u"leaf_spec",b"leaf_spec",u"max_depth",b"max_depth",u"min_depth",b"min_depth"]) -> None: ...
global___ProofSpec = ProofSpec

class InnerSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CHILD_ORDER_FIELD_NUMBER: builtins.int
    CHILD_SIZE_FIELD_NUMBER: builtins.int
    MIN_PREFIX_LENGTH_FIELD_NUMBER: builtins.int
    MAX_PREFIX_LENGTH_FIELD_NUMBER: builtins.int
    EMPTY_CHILD_FIELD_NUMBER: builtins.int
    HASH_FIELD_NUMBER: builtins.int

    @property
    def child_order(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    child_size: builtins.int = ...
    min_prefix_length: builtins.int = ...
    max_prefix_length: builtins.int = ...
    empty_child: builtins.bytes = ...
    hash: global___HashOp.V = ...

    def __init__(self,
        *,
        child_order : typing.Optional[typing.Iterable[builtins.int]] = ...,
        child_size : builtins.int = ...,
        min_prefix_length : builtins.int = ...,
        max_prefix_length : builtins.int = ...,
        empty_child : builtins.bytes = ...,
        hash : global___HashOp.V = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"child_order",b"child_order",u"child_size",b"child_size",u"empty_child",b"empty_child",u"hash",b"hash",u"max_prefix_length",b"max_prefix_length",u"min_prefix_length",b"min_prefix_length"]) -> None: ...
global___InnerSpec = InnerSpec

class BatchProof(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ENTRIES_FIELD_NUMBER: builtins.int

    @property
    def entries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BatchEntry]: ...

    def __init__(self,
        *,
        entries : typing.Optional[typing.Iterable[global___BatchEntry]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"entries",b"entries"]) -> None: ...
global___BatchProof = BatchProof

class BatchEntry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    EXIST_FIELD_NUMBER: builtins.int
    NONEXIST_FIELD_NUMBER: builtins.int

    @property
    def exist(self) -> global___ExistenceProof: ...

    @property
    def nonexist(self) -> global___NonExistenceProof: ...

    def __init__(self,
        *,
        exist : typing.Optional[global___ExistenceProof] = ...,
        nonexist : typing.Optional[global___NonExistenceProof] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"exist",b"exist",u"nonexist",b"nonexist",u"proof",b"proof"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"exist",b"exist",u"nonexist",b"nonexist",u"proof",b"proof"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"proof",b"proof"]) -> typing.Optional[typing_extensions.Literal["exist","nonexist"]]: ...
global___BatchEntry = BatchEntry

class CompressedBatchProof(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ENTRIES_FIELD_NUMBER: builtins.int
    LOOKUP_INNERS_FIELD_NUMBER: builtins.int

    @property
    def entries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CompressedBatchEntry]: ...

    @property
    def lookup_inners(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InnerOp]: ...

    def __init__(self,
        *,
        entries : typing.Optional[typing.Iterable[global___CompressedBatchEntry]] = ...,
        lookup_inners : typing.Optional[typing.Iterable[global___InnerOp]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"entries",b"entries",u"lookup_inners",b"lookup_inners"]) -> None: ...
global___CompressedBatchProof = CompressedBatchProof

class CompressedBatchEntry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    EXIST_FIELD_NUMBER: builtins.int
    NONEXIST_FIELD_NUMBER: builtins.int

    @property
    def exist(self) -> global___CompressedExistenceProof: ...

    @property
    def nonexist(self) -> global___CompressedNonExistenceProof: ...

    def __init__(self,
        *,
        exist : typing.Optional[global___CompressedExistenceProof] = ...,
        nonexist : typing.Optional[global___CompressedNonExistenceProof] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"exist",b"exist",u"nonexist",b"nonexist",u"proof",b"proof"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"exist",b"exist",u"nonexist",b"nonexist",u"proof",b"proof"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"proof",b"proof"]) -> typing.Optional[typing_extensions.Literal["exist","nonexist"]]: ...
global___CompressedBatchEntry = CompressedBatchEntry

class CompressedExistenceProof(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    LEAF_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    key: builtins.bytes = ...
    value: builtins.bytes = ...

    @property
    def path(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...

    @property
    def leaf(self) -> global___LeafOp: ...

    def __init__(self,
        *,
        key : builtins.bytes = ...,
        value : builtins.bytes = ...,
        leaf : typing.Optional[global___LeafOp] = ...,
        path : typing.Optional[typing.Iterable[builtins.int]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"leaf",b"leaf"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"key",b"key",u"leaf",b"leaf",u"path",b"path",u"value",b"value"]) -> None: ...
global___CompressedExistenceProof = CompressedExistenceProof

class CompressedNonExistenceProof(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    KEY_FIELD_NUMBER: builtins.int
    LEFT_FIELD_NUMBER: builtins.int
    RIGHT_FIELD_NUMBER: builtins.int
    key: builtins.bytes = ...

    @property
    def left(self) -> global___CompressedExistenceProof: ...

    @property
    def right(self) -> global___CompressedExistenceProof: ...

    def __init__(self,
        *,
        key : builtins.bytes = ...,
        left : typing.Optional[global___CompressedExistenceProof] = ...,
        right : typing.Optional[global___CompressedExistenceProof] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"left",b"left",u"right",b"right"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"key",b"key",u"left",b"left",u"right",b"right"]) -> None: ...
global___CompressedNonExistenceProof = CompressedNonExistenceProof



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.crypto.multisig.v1beta1.multisig_pb2
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class SignMode(metaclass=_SignMode):
    V = typing.NewType('V', builtins.int)

global___SignMode = SignMode

SIGN_MODE_UNSPECIFIED = SignMode.V(0)
SIGN_MODE_DIRECT = SignMode.V(1)
SIGN_MODE_TEXTUAL = SignMode.V(2)
SIGN_MODE_LEGACY_AMINO_JSON = SignMode.V(127)

class _SignMode(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[SignMode.V], builtins.type):  # type: ignore
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    SIGN_MODE_UNSPECIFIED = SignMode.V(0)
    SIGN_MODE_DIRECT = SignMode.V(1)
    SIGN_MODE_TEXTUAL = SignMode.V(2)
    SIGN_MODE_LEGACY_AMINO_JSON = SignMode.V(127)

class SignatureDescriptors(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SIGNATURES_FIELD_NUMBER: builtins.int

    @property
    def signatures(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SignatureDescriptor]: ...

    def __init__(self,
        *,
        signatures : typing.Optional[typing.Iterable[global___SignatureDescriptor]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"signatures",b"signatures"]) -> None: ...
global___SignatureDescriptors = SignatureDescriptors

class SignatureDescriptor(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class Data(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        class Single(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
            MODE_FIELD_NUMBER: builtins.int
            SIGNATURE_FIELD_NUMBER: builtins.int
            mode: global___SignMode.V = ...
            signature: builtins.bytes = ...

            def __init__(self,
                *,
                mode : global___SignMode.V = ...,
                signature : builtins.bytes = ...,
                ) -> None: ...
            def ClearField(self, field_name: typing_extensions.Literal[u"mode",b"mode",u"signature",b"signature"]) -> None: ...

        class Multi(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
            BITARRAY_FIELD_NUMBER: builtins.int
            SIGNATURES_FIELD_NUMBER: builtins.int

            @property
            def bitarray(self) -> cosmos.crypto.multisig.v1beta1.multisig_pb2.CompactBitArray: ...

            @property
            def signatures(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SignatureDescriptor.Data]: ...

            def __init__(self,
                *,
                bitarray : typing.Optional[cosmos.crypto.multisig.v1beta1.multisig_pb2.CompactBitArray] = ...,
                signatures : typing.Optional[typing.Iterable[global___SignatureDescriptor.Data]] = ...,
                ) -> None: ...
            def HasField(self, field_name: typing_extensions.Literal[u"bitarray",b"bitarray"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing_extensions.Literal[u"bitarray",b"bitarray",u"signatures",b"signatures"]) -> None: ...

        SINGLE_FIELD_NUMBER: builtins.int
        MULTI_FIELD_NUMBER: builtins.int

        @property
        def single(self) -> global___SignatureDescriptor.Data.Single: ...

        @property
        def multi(self) -> global___SignatureDescriptor.Data.Multi: ...

        def __init__(self,
            *,
            single : typing.Optional[global___SignatureDescriptor.Data.Single] = ...,
            multi : typing.Optional[global___SignatureDescriptor.Data.Multi] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"multi",b"multi",u"single",b"single",u"sum",b"sum"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"multi",b"multi",u"single",b"single",u"sum",b"sum"]) -> None: ...
        def WhichOneof(self, oneof_group: typing_extensions.Literal[u"sum",b"sum"]) -> typing.Optional[typing_extensions.Literal["single","multi"]]: ...

    PUBLIC_KEY_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    SEQUENCE_FIELD_NUMBER: builtins.int
    sequence: builtins.int = ...

    @property
    def public_key(self) -> google.protobuf.any_pb2.Any: ...

    @property
    def data(self) -> global___SignatureDescriptor.Data: ...

    def __init__(self,
        *,
        public_key : typing.Optional[google.protobuf.any_pb2.Any] = ...,
        data : typing.Optional[global___SignatureDescriptor.Data] = ...,
        sequence : builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"data",b"data",u"public_key",b"public_key"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"data",b"data",u"public_key",b"public_key",u"sequence",b"sequence"]) -> None: ...
global___SignatureDescriptor = SignatureDescriptor



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Params(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COMMUNITY_TAX_FIELD_NUMBER: builtins.int
    BASE_PROPOSER_REWARD_FIELD_NUMBER: builtins.int
    BONUS_PROPOSER_REWARD_FIELD_NUMBER: builtins.int
    WITHDRAW_ADDR_ENABLED_FIELD_NUMBER: builtins.int
    community_tax: typing.Text = ...
    base_proposer_reward: typing.Text = ...
    bonus_proposer_reward: typing.Text = ...
    withdraw_addr_enabled: builtins.bool = ...

    def __init__(self,
        *,
        community_tax : typing.Text = ...,
        base_proposer_reward : typing.Text = ...,
        bonus_proposer_reward : typing.Text = ...,
        withdraw_addr_enabled : builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"base_proposer_reward",b"base_proposer_reward",u"bonus_proposer_reward",b"bonus_proposer_reward",u"community_tax",b"community_tax",u"withdraw_addr_enabled",b"withdraw_addr_enabled"]) -> None: ...
global___Params = Params

class ValidatorHistoricalRewards(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CUMULATIVE_REWARD_RATIO_FIELD_NUMBER: builtins.int
    REFERENCE_COUNT_FIELD_NUMBER: builtins.int
    reference_count: builtins.int = ...

    @property
    def cumulative_reward_ratio(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.DecCoin]: ...

    def __init__(self,
        *,
        cumulative_reward_ratio : typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.DecCoin]] = ...,
        reference_count : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"cumulative_reward_ratio",b"cumulative_reward_ratio",u"reference_count",b"reference_count"]) -> None: ...
global___ValidatorHistoricalRewards = ValidatorHistoricalRewards

class ValidatorCurrentRewards(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    REWARDS_FIELD_NUMBER: builtins.int
    PERIOD_FIELD_NUMBER: builtins.int
    period: builtins.int = ...

    @property
    def rewards(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.DecCoin]: ...

    def __init__(self,
        *,
        rewards : typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.DecCoin]] = ...,
        period : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"period",b"period",u"rewards",b"rewards"]) -> None: ...
global___ValidatorCurrentRewards = ValidatorCurrentRewards

class ValidatorAccumulatedCommission(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COMMISSION_FIELD_NUMBER: builtins.int

    @property
    def commission(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.DecCoin]: ...

    def __init__(self,
        *,
        commission : typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.DecCoin]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"commission",b"commission"]) -> None: ...
global___ValidatorAccumulatedCommission = ValidatorAccumulatedCommission

class ValidatorOutstandingRewards(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    REWARDS_FIELD_NUMBER: builtins.int

    @property
    def rewards(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.DecCoin]: ...

    def __init__(self,
        *,
        rewards : typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.DecCoin]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"rewards",b"rewards"]) -> None: ...
global___ValidatorOutstandingRewards = ValidatorOutstandingRewards

class ValidatorSlashEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALIDATOR_PERIOD_FIELD_NUMBER: builtins.int
    FRACTION_FIELD_NUMBER: builtins.int
    validator_period: builtins.int = ...
    fraction: typing.Text = ...

    def __init__(self,
        *,
        validator_period : builtins.int = ...,
        fraction : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"fraction",b"fraction",u"validator_period",b"validator_period"]) -> None: ...
global___ValidatorSlashEvent = ValidatorSlashEvent

class ValidatorSlashEvents(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALIDATOR_SLASH_EVENTS_FIELD_NUMBER: builtins.int

    @property
    def validator_slash_events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ValidatorSlashEvent]: ...

    def __init__(self,
        *,
        validator_slash_events : typing.Optional[typing.Iterable[global___ValidatorSlashEvent]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"validator_slash_events",b"validator_slash_events"]) -> None: ...
global___ValidatorSlashEvents = ValidatorSlashEvents

class FeePool(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COMMUNITY_POOL_FIELD_NUMBER: builtins.int

    @property
    def community_pool(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.DecCoin]: ...

    def __init__(self,
        *,
        community_pool : typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.DecCoin]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"community_pool",b"community_pool"]) -> None: ...
global___FeePool = FeePool

class CommunityPoolSpendProposal(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    RECIPIENT_FIELD_NUMBER: builtins.int
    AMOUNT_FIELD_NUMBER: builtins.int
    title: typing.Text = ...
    description: typing.Text = ...
    recipient: typing.Text = ...

    @property
    def amount(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...

    def __init__(self,
        *,
        title : typing.Text = ...,
        description : typing.Text = ...,
        recipient : typing.Text = ...,
        amount : typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"amount",b"amount",u"description",b"description",u"recipient",b"recipient",u"title",b"title"]) -> None: ...
global___CommunityPoolSpendProposal = CommunityPoolSpendProposal

class DelegatorStartingInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PREVIOUS_PERIOD_FIELD_NUMBER: builtins.int
    STAKE_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    previous_period: builtins.int = ...
    stake: typing.Text = ...
    height: builtins.int = ...

    def __init__(self,
        *,
        previous_period : builtins.int = ...,
        stake : typing.Text = ...,
        height : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"height",b"height",u"previous_period",b"previous_period",u"stake",b"stake"]) -> None: ...
global___DelegatorStartingInfo = DelegatorStartingInfo

class DelegationDelegatorReward(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    REWARD_FIELD_NUMBER: builtins.int
    validator_address: typing.Text = ...

    @property
    def reward(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.DecCoin]: ...

    def __init__(self,
        *,
        validator_address : typing.Text = ...,
        reward : typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.DecCoin]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"reward",b"reward",u"validator_address",b"validator_address"]) -> None: ...
global___DelegationDelegatorReward = DelegationDelegatorReward

class CommunityPoolSpendProposalWithDeposit(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    RECIPIENT_FIELD_NUMBER: builtins.int
    AMOUNT_FIELD_NUMBER: builtins.int
    DEPOSIT_FIELD_NUMBER: builtins.int
    title: typing.Text = ...
    description: typing.Text = ...
    recipient: typing.Text = ...
    amount: typing.Text = ...
    deposit: typing.Text = ...

    def __init__(self,
        *,
        title : typing.Text = ...,
        description : typing.Text = ...,
        recipient : typing.Text = ...,
        amount : typing.Text = ...,
        deposit : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"amount",b"amount",u"deposit",b"deposit",u"description",b"description",u"recipient",b"recipient",u"title",b"title"]) -> None: ...
global___CommunityPoolSpendProposalWithDeposit = CommunityPoolSpendProposalWithDeposit



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class PageRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    KEY_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    LIMIT_FIELD_NUMBER: builtins.int
    COUNT_TOTAL_FIELD_NUMBER: builtins.int
    key: builtins.bytes = ...
    offset: builtins.int = ...
    limit: builtins.int = ...
    count_total: builtins.bool = ...

    def __init__(self,
        *,
        key : builtins.bytes = ...,
        offset : builtins.int = ...,
        limit : builtins.int = ...,
        count_total : builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"count_total",b"count_total",u"key",b"key",u"limit",b"limit",u"offset",b"offset"]) -> None: ...
global___PageRequest = PageRequest

class PageResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    NEXT_KEY_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    next_key: builtins.bytes = ...
    total: builtins.int = ...

    def __init__(self,
        *,
        next_key : builtins.bytes = ...,
        total : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"next_key",b"next_key",u"total",b"total"]) -> None: ...
global___PageResponse = PageResponse
